@@ -7,7 +7,7 @@ use Kavorka::Signature ();
 package Kavorka::Sub;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.007';
+our $VERSION   = '0.008';
 
 use Text::Balanced qw( extract_codeblock extract_bracketed );
 use Parse::Keyword {};
@@ -358,10 +358,14 @@ the signature code injected into it.
 
 =over
 
-=item C<parse>, C<parse_name>, C<parse_attributes>, C<parse_prototype>,
-C<parse_signature>
+=item C<parse>,
+C<parse_subname>,
+C<parse_signature>,
+C<parse_prototype>,
+C<parse_attributes>,
+C<parse_body> 
 
-Internal methods used to parse a signature. It only makes sense to call
+Internal methods used to parse a subroutine. It only makes sense to call
 these from a L<Parse::Keyword> parser, but may make sense to override
 them in classes consuming the Kavorka::Sub role.
 
